@@ -76,7 +76,7 @@ same_class <- function(x, y) {
   identical(class(x), class(y))
 }
 diff_class <- function(x, y) {
-  difference(fmt = "Classes differ: %s is not %s", klass(x), klass(y))
+  difference(fmt = "Classes differ: %s is not %s", format_class(class(x)), format_class(class(y)))
 }
 
 same_attr <- function(x, y) {
@@ -275,7 +275,7 @@ compare.numeric <- function(x, y,
 
 #' @export
 #' @rdname compare
-testthat_tolerance <- function(x) {
+testthat_tolerance <- function() {
   if (identical(capabilities("long.double"), FALSE)) {
     skip("Long doubles not available and `tolerance` not supplied")
   }
