@@ -1,6 +1,3 @@
-#' @include reporter.R
-NULL
-
 # To allow the Java-style class name format that Jenkins prefers,
 # "package_name_or_domain.ClassName", allow "."s in the class name.
 classnameOK <- function(text) {
@@ -28,6 +25,7 @@ classnameOK <- function(text) {
 #' \url{http://llg.cubic.org/docs/junit/}
 #'
 #' @export
+#' @family reporters
 JunitReporter <- R6::R6Class("JunitReporter",
   inherit = Reporter,
   public = list(
@@ -44,7 +42,7 @@ JunitReporter <- R6::R6Class("JunitReporter",
     file_name = NULL,
 
     elapsed_time = function() {
-      time <- round((private$proctime() - self$timer)[["elapsed"]], 2)
+      time <- (private$proctime() - self$timer)[["elapsed"]]
       self$timer <- private$proctime()
       time
     },
@@ -58,9 +56,7 @@ JunitReporter <- R6::R6Class("JunitReporter",
     },
 
     start_reporter = function() {
-      if (!is_installed("xml2")) {
-        stop("Please install the `xml2` package", call. = FALSE)
-      }
+      check_installed("xml2", "JunitReporter")
 
       self$timer <- private$proctime()
       self$doc <- xml2::xml_new_document()
@@ -74,7 +70,7 @@ JunitReporter <- R6::R6Class("JunitReporter",
 
     start_test = function(context, test) {
       if (is.null(context)) {
-        context(context_name(self$file_name))
+        context_start_file(self$file_name)
       }
     },
 
@@ -115,22 +111,23 @@ JunitReporter <- R6::R6Class("JunitReporter",
       )
 
       first_line <- function(x) {
-        paste0(strsplit(x$message, split = "\n")[[1]][1], src_loc(x$srcref))
+        loc <- expectation_location(x)
+        paste0(strsplit(x$message, split = "\n")[[1]][1], " (", loc, ")")
       }
 
       # add an extra XML child node if not a success
       if (expectation_error(result)) {
         # "type" in Java is the exception class
         error <- xml2::xml_add_child(testcase, "error", type = "error", message = first_line(result))
-        xml2::xml_text(error) <- format(result)
+        xml2::xml_text(error) <- crayon::strip_style(format(result))
         self$errors <- self$errors + 1
       } else if (expectation_failure(result)) {
         # "type" in Java is the type of assertion that failed
         failure <- xml2::xml_add_child(testcase, "failure", type = "failure", message = first_line(result))
-        xml2::xml_text(failure) <- format(result)
+        xml2::xml_text(failure) <- crayon::strip_style(format(result))
         self$failures <- self$failures + 1
       } else if (expectation_skip(result)) {
-        xml2::xml_add_child(testcase, "skipped")
+        xml2::xml_add_child(testcase, "skipped", message = first_line(result))
         self$skipped <- self$skipped + 1
       }
     },
@@ -141,7 +138,7 @@ JunitReporter <- R6::R6Class("JunitReporter",
       } else if (inherits(self$out, "connection")) {
         file <- tempfile()
         xml2::write_xml(self$doc, file, format = TRUE)
-        write_lines(read_lines(file), self$out)
+        cat(brio::read_file(file), file = self$out)
       } else {
         stop("unsupported output type: ", toString(self$out))
       }
@@ -153,10 +150,34 @@ JunitReporter <- R6::R6Class("JunitReporter",
       proc.time()
     },
     timestamp = function() {
-      toString(Sys.time())
+      strftime(Sys.time(), "%Y-%m-%dT%H:%M:%SZ", tz = "UTC")
     },
     hostname = function() {
       Sys.info()[["nodename"]]
     }
   ) # private
 )
+
+# Fix components of JunitReporter that otherwise vary from run-to-run
+#
+# The following functions need to be mocked out to run a unit test
+# against static contents of reporters/junit.txt:
+#   - proctime - originally wrapper for proc.time()
+#   - timestamp - originally wrapper for toString(Sys.time())
+#   - hostname  - originally wrapper for Sys.info()[["nodename"]]
+#
+JunitReporterMock <- R6::R6Class("JunitReporterMock",
+  inherit = JunitReporter,
+  public  = list(),
+  private = list(
+    proctime = function() {
+      c(user = 0, system = 0, elapsed = 0)
+    },
+    timestamp = function() {
+      "1999:12:31 23:59:59"
+    },
+    hostname = function() {
+      "nodename"
+    }
+  )
+)
