@@ -1,7 +1,7 @@
 #' Test reporter: interactive progress bar of errors.
 #'
 #' @description
-#' `ProgressReporter` is designed for interactively use. It's goal is to
+#' `ProgressReporter` is designed for interactive use. Its goal is to
 #' give you actionable insights to help you understand the status of your
 #' code. This reporter also praises you from time-to-time if all your tests
 #' pass. It's the default reporter for [test_dir()].
@@ -34,6 +34,7 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
     n_fail = 0,
 
     frames = NULL,
+    dynamic = FALSE,
 
     ctxt_start_time = NULL,
     ctxt_issues = NULL,
@@ -46,7 +47,7 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
     file_name = "",
 
     initialize = function(show_praise = TRUE,
-                          max_failures = getOption("testthat.progress.max_fails", 10L),
+                          max_failures = testthat_max_fails(),
                           min_time = 0.1,
                           update_interval = 0.1,
                           verbose_skips = getOption("testthat.progress.verbose_skips", TRUE),
@@ -60,9 +61,11 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
       self$update_interval <- update_interval
 
       self$skips <- Stack$new()
+      self$ctxt_issues <- Stack$new()
 
       # Capture at init so not affected by test settings
       self$frames <- cli::get_spinner()$frames
+      self$dynamic <- cli::is_dynamic_tty()
     },
 
     is_full = function() {
@@ -98,11 +101,12 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
 
     show_header = function() {
       self$cat_line(
-        cli::symbol$tick, " |  OK ",
+        colourise(cli::symbol$tick, "success"), " | ",
         colourise("F", "failure"), " ",
         colourise("W", "warning"), " ",
-        colourise("S", "skip"), " | ",
-        "Context"
+        colourise("S", "skip"), " ",
+        colourise(" OK", "success"),
+        " | ", "Context"
       )
     },
 
@@ -142,22 +146,23 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
         if (n == 0) {
           " "
         } else {
-          n
+          colourise(n, type)
         }
       }
 
       message <- paste0(
-        status, " | ", sprintf("%3d", data$n_ok), " ",
+        status, " | ",
         col_format(data$n_fail, "fail"), " ",
         col_format(data$n_warn, "warn"), " ",
-        col_format(data$n_skip, "skip"), " | ",
-        data$name
+        col_format(data$n_skip, "skip"), " ",
+        sprintf("%3d", data$n_ok),
+        " | ", data$name
       )
 
       if (complete && time > self$min_time) {
         message <- paste0(
           message,
-          cli::col_cyan(sprintf(" [%.1f s]", time))
+          cli::col_grey(sprintf(" [%.1fs]", time))
         )
       }
 
@@ -168,9 +173,17 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
 
       if (!complete) {
         message <- strpad(message, self$width)
-        self$cat_tight("\r", message)
+        self$cat_tight(self$cr(), message)
       } else {
-        self$cat_line("\r", message)
+        self$cat_line(self$cr(), message)
+      }
+    },
+
+    cr = function() {
+      if (self$dynamic) {
+        "\r"
+      } else {
+        "\n"
       }
     },
 
@@ -185,8 +198,19 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
       }
 
       self$show_status(complete = TRUE, time = time[[3]])
-
       self$report_issues(self$ctxt_issues)
+
+      if (self$is_full()) {
+        snapshotter <- get_snapshotter()
+        if (!is.null(snapshotter)) {
+          snapshotter$end_file()
+        }
+
+        stop_reporter(paste0(
+          "Maximum number of failures exceeded; quitting at end of file.\n",
+          "Increase this number with (e.g.) `Sys.setenv('TESTTHAT_MAX_FAILS' = Inf)`"
+        ))
+      }
     },
 
     add_result = function(context, test, result) {
@@ -212,15 +236,6 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
         self$ctxt_n_ok <- self$ctxt_n_ok + 1
       }
 
-      if (self$is_full()) {
-        self$local_user_output()
-        self$end_context()
-        stop_reporter(paste0(
-          "Maximum number of failures exceeded; quitting early.\n",
-          "You can increase this number by setting `options(testthat.progress.max_fails)`"
-        ))
-      }
-
       self$show_status()
     },
 
@@ -295,6 +310,16 @@ ProgressReporter <- R6::R6Class("ProgressReporter",
   )
 )
 
+testthat_max_fails <- function() {
+  val <- getOption("testthat.progress.max_fails")
+
+  if (is.null(val)) {
+    env <- Sys.getenv("TESTTHAT_MAX_FAILS")
+    val <- if (!identical(env, "")) as.numeric(env) else 10
+  }
+  val
+}
+
 #' @export
 #' @rdname ProgressReporter
 CompactProgressReporter <- R6::R6Class("CompactProgressReporter",
@@ -351,7 +376,7 @@ CompactProgressReporter <- R6::R6Class("CompactProgressReporter",
     show_status = function(complete = NULL) {
       self$local_user_output()
       status <- summary_line(self$n_fail, self$n_warn, self$n_skip, self$n_ok)
-      self$cat_tight("\r", status)
+      self$cat_tight(self$cr(), status)
     }
 
   )
@@ -383,7 +408,7 @@ ParallelProgressReporter <- R6::R6Class("ParallelProgressReporter",
         self$files[[file]] <- list(
           issues = Stack$new(),
           n_fail = 0L,
-          n_skip_ = 0L,
+          n_skip = 0L,
           n_warn = 0L,
           n_ok = 0L,
           name = context_name(file),
@@ -407,7 +432,7 @@ ParallelProgressReporter <- R6::R6Class("ParallelProgressReporter",
 
       # Workaround for https://github.com/rstudio/rstudio/issues/7649
       if (self$is_rstudio) {
-        self$cat_tight(strpad("\r", self$width + 1)) # +1 for \r
+        self$cat_tight(strpad(self$cr(), self$width + 1)) # +1 for \r
       }
       self$show_status(complete = TRUE, time = time[[3]], pad = TRUE)
       self$report_issues(fsts$issues)
@@ -417,7 +442,7 @@ ParallelProgressReporter <- R6::R6Class("ParallelProgressReporter",
     },
 
     end_reporter = function() {
-      self$cat_tight("\r", strpad("", self$width))
+      self$cat_tight(self$cr(), strpad("", self$width))
       super$end_reporter()
     },
 
@@ -467,7 +492,7 @@ ParallelProgressReporter <- R6::R6Class("ParallelProgressReporter",
       )
       message <- strpad(message, self$width)
       message <- crayon::col_substr(message, 1, self$width)
-      self$cat_tight("\r", message)
+      self$cat_tight(self$cr(), message)
     }
   )
 )
@@ -508,7 +533,10 @@ strpad <- function(x, width = cli::console_width()) {
 }
 
 skip_bullets <- function(skips) {
-  skips <- gsub("Reason: ", "", unlist(skips))
+  skips <- unlist(skips)
+  skips <- gsub("Reason: ", "", skips)
+  skips <- gsub(":?\n(\n|.)+", "", skips) # only show first line
+
   tbl <- table(skips)
   paste0(cli::symbol$bullet, " ", names(tbl), " (", tbl, ")")
 }
