@@ -1,22 +1,26 @@
 #' Verify output
 #'
 #' @description
-#' This is a regression test that records interwoven code and output into a
-#' file, in a similar way to kniting an `.Rmd` (but see caveats below).
+#' `r lifecycle::badge("superseded")`
 #'
-#' `verify_output()` designed particularly for testing print methods and error
+#' This function is superseded in favour of `expect_snapshot()` and friends.
+#'
+#' This is a regression test that records interwoven code and output into a
+#' file, in a similar way to knitting an `.Rmd` file (but see caveats below).
+#'
+#' `verify_output()` is designed particularly for testing print methods and error
 #' messages, where the primary goal is to ensure that the output is helpful to
 #' a human. Obviously, you can't test that with code, so the best you can do is
-#' make the results explicit by saving them to text file. This makes the output
-#' easy to see in code reviews, and ensures that you don't change the output
-#' accidentally.
+#' make the results explicit by saving them to a text file. This makes the output
+#' easy to verify in code reviews, and ensures that you don't change the output
+#' by accident.
 #'
 #' `verify_output()` is designed to be used with git: to see what has changed
 #' from the previous run, you'll need to use `git diff` or similar.
 #'
 #' @section Syntax:
 #' `verify_output()` can only capture the abstract syntax tree, losing all
-#' whitespace and comments. To mildy offset this limitation:
+#' whitespace and comments. To mildly offset this limitation:
 #'
 #' - Strings are converted to R comments in the output.
 #' - Strings starting with `# ` are converted to headers in the output.
@@ -30,10 +34,10 @@
 #'
 #' @param path Path to record results.
 #'
-#'   This should usually be a call to [test_path()] to ensures that same path
-#'   is used when run interactively (when the working directory is typically
-#'   the project root), and when run as an autmated test (when the working
-#'   directory will be `tests/testthat`).
+#'   This should usually be a call to [test_path()] in order to ensure that
+#'   the same path is used when run interactively (when the working directory
+#'   is typically the project root), and when run as an automated test (when
+#'   the working directory will be `tests/testthat`).
 #' @param code Code to execute. This will usually be a multiline expression
 #'   contained within `{}` (similarly to `test_that()` calls).
 #' @param width Width of console output
@@ -43,39 +47,23 @@
 #'   test on your CI platforms that don't support UTF-8 (e.g. Windows).
 #' @param env The environment to evaluate `code` in.
 #' @export
-#' @examples
-#' # The first argument would usually be `test_path("informative-name.txt"`)
-#' # but that is not permitted in examples
-#' path <- tempfile()
-#' verify_output(path, {
-#'    head(mtcars)
-#'    log(-10)
-#'    "a" * 3
-#' })
-#' writeLines(readLines(path))
-#'
-#' # Use strings to create comments in the output
-#' verify_output(tempfile(), {
-#'    "Print method"
-#'    head(mtcars)
-#'
-#'    "Warning"
-#'    log(-10)
-#'
-#'    "Error"
-#'    "a" * 3
-#' })
-#'
-#' # Use strings starting with # to create headings
-#' verify_output(tempfile(), {
-#'    "# Base functions"
-#'    head(mtcars)
-#'    log(-10)
-#'    "a" * 3
-#' })
+#' @keywords internal
 verify_output <- function(path, code, width = 80, crayon = FALSE,
                           unicode = FALSE, env = caller_env()) {
+
+  local_reproducible_output(width = width, crayon = crayon, unicode = unicode)
+
   expr <- substitute(code)
+  output <- verify_exec(expr, env = env)
+
+  if (!interactive() && on_cran()) {
+    skip("On CRAN")
+  }
+  compare_file(path, output, update = TRUE)
+  invisible()
+}
+
+verify_exec <- function(expr, env = caller_env(), replay = output_replay) {
 
   if (is_call(expr, "{")) {
     exprs <- as.list(expr[-1])
@@ -83,30 +71,20 @@ verify_output <- function(path, code, width = 80, crayon = FALSE,
     exprs <- list(expr)
   }
 
-  withr::local_options(list(
-    width = width,
-    crayon.enabled = crayon,
-    cli.unicode = unicode
-  ))
-  withr::local_envvar(list(RSTUDIO_CONSOLE_WIDTH = width))
+  withr::local_pdf(tempfile())
+  grDevices::dev.control(displaylist = "enable")
 
   exprs <- lapply(exprs, function(x) if (is.character(x)) paste0("# ", x) else expr_deparse(x))
   source <- unlist(exprs, recursive = FALSE)
 
-  # Open temporary new device
-  grDevices::png(filename = tempfile())
-  grDevices::dev.control(displaylist = "enable")
-  dev <- grDevices::dev.cur()
-  on.exit(grDevices::dev.off(dev), add = TRUE)
-
-  results <- evaluate::evaluate(source, envir = env, new_device = FALSE)
-  output <- unlist(lapply(results, output_replay))
-
-  if (is_testing() && on_cran()) {
-    skip("On CRAN")
-  }
-  compare_file(path, output, update = TRUE)
-  invisible()
+  handler <- evaluate::new_output_handler(value = testthat_print)
+  results <- evaluate::evaluate(source, envir = env,
+    new_device = FALSE,
+    output_handler = handler
+  )
+  output <- unlist(lapply(results, replay))
+  output <- gsub("\r", "", output, fixed = TRUE)
+  output
 }
 
 output_replay <- function(x) {
