@@ -3,39 +3,40 @@ test_that("compare state works correctly", {
   dir.create(loc)
 
   empty <- dir_state(loc)
-  expect_that(length(empty), equals(0))
+  expect_equal(length(empty), 0)
 
   file.create(file.path(loc, "test-1.txt"))
   one <- dir_state(loc)
-  expect_that(length(one), equals(1))
-  expect_that(basename(names(one)), equals("test-1.txt"))
+  expect_equal(length(one), 1)
+  expect_equal(basename(names(one)), "test-1.txt")
 
   diff <- compare_state(empty, one)
-  expect_that(diff$n, equals(1))
-  expect_that(basename(diff$added), equals("test-1.txt"))
+  expect_equal(diff$n, 1)
+  expect_equal(basename(diff$added), "test-1.txt")
 
   write.table(mtcars, file.path(loc, "test-1.txt"))
   diff <- compare_state(one, dir_state(loc))
-  expect_that(diff$n, equals(1))
-  expect_that(basename(diff$modified), equals("test-1.txt"))
+  expect_equal(diff$n, 1)
+  expect_equal(basename(diff$modified), "test-1.txt")
 
   file.rename(file.path(loc, "test-1.txt"), file.path(loc, "test-2.txt"))
   diff <- compare_state(one, dir_state(loc))
-  expect_that(diff$n, equals(2))
-  expect_that(basename(diff$deleted), equals("test-1.txt"))
-  expect_that(basename(diff$added), equals("test-2.txt"))
+  expect_equal(diff$n, 2)
+  expect_equal(basename(diff$deleted), "test-1.txt")
+  expect_equal(basename(diff$added), "test-2.txt")
 
   diff <- compare_state(
     c(file1 = "62da2", file2 = "e14a6", file3 = "6e6dd"),
     c(file1 = "62da2", file2 = "e14a6", file21 = "532fa", file3 = "3f4sa")
   )
-  expect_that(diff$n, equals(2))
-  expect_that(basename(diff$added), equals("file21"))
-  expect_that(basename(diff$modified), equals("file3"))
+  expect_equal(diff$n, 2)
+  expect_equal(basename(diff$added), "file21")
+  expect_equal(basename(diff$modified), "file3")
 })
 
 test_that("watcher works correctly", {
   skip_on_ci()
+  skip_on_os("windows")
   skip_on_cran()
   if (Sys.which("bash") == "") {
     skip("bash not available")
@@ -44,7 +45,7 @@ test_that("watcher works correctly", {
     skip("touch (or which) not available")
   }
 
-  loc <- tempfile("watcher", tmpdir = "/tmp")
+  loc <- tempfile("watcher")
   dir.create(loc)
 
   code_path <- file.path(loc, "R")
@@ -66,18 +67,18 @@ test_that("watcher works correctly", {
   }
 
   test.added <- function(added, deleted, modified) {
-    expect_that(length(added), equals(1))
-    expect_true(grepl("test1.R", added))
-    expect_that(length(deleted), equals(0))
-    expect_that(length(modified), equals(0))
+    expect_equal(length(added), 1)
+    expect_equal(grepl("test1.R", added), TRUE)
+    expect_equal(length(deleted), 0)
+    expect_equal(length(modified), 0)
     FALSE
   }
 
   test.removed <- function(added, deleted, modified) {
-    expect_that(length(added), equals(0))
-    expect_that(length(deleted), equals(1))
-    expect_true(grepl("test1.R", deleted))
-    expect_that(length(modified), equals(0))
+    expect_equal(length(added), 0)
+    expect_equal(length(deleted), 1)
+    expect_equal(grepl("test1.R", deleted), TRUE)
+    expect_equal(length(modified), 0)
     FALSE
   }
 
